# anchorscad-utils

Utility libraries for AnchorSCAD. This package provides several utilities for working with AnchorSCAD but are not specific to AnchorSCAD. You're welcome to use them in your own projects.

## Features

- **Colour Handling**: A comprehensive colour management system supporting RGB, RGBA, HSV, and named colours. [Documentation](https://github.com/owebeeone/anchorscad-utils/blob/main/colours.md)

- **OpenSCAD Finder**: Functionality to locate and determine capabilities of OpenSCAD installation details. [Documentation](https://github.com/owebeeone/anchorscad-utils/blob/main/openscad_finder.md)

- **Process Manager**: A system for managing concurrent subprocess execution. [Documentation](https://github.com/owebeeone/anchorscad-utils/blob/main/process_manager.md)

## Installation

Install via pip:

```bash
pip install anchorscad-utils
```

## License

This project is licensed under the GNU Lesser General Public License v2.1 (LGPL-2.1). See the [LICENSE](https://github.com/owebeeone/anchorscad-utils/blob/main/LICENSE) file for details.

## Contributing

Contributions are welcome! Please feel free to submit a Pull Request.
